@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-import gtk
+from gi.repository import Gdk
+from gi.repository import Gtk
 import gobject
 from gettext import gettext as _
 import gnomedvb
@@ -33,10 +34,10 @@ from gnomedvb.ui.timers.MessageDialogs import TimerFailureDialog
 from gnomedvb.ui.preferences.Preferences import Preferences
 from gnomedvb.ui.recordings.RecordingsDialog import RecordingsDialog
    
-class ControlCenterWindow(gtk.Window):
+class ControlCenterWindow(Gtk.Window):
 
     def __init__(self, model):
-        gtk.Window.__init__(self)
+        gobject.GObject.__init__(self)
         
         self.runningnextstore = None
         self.scrolledrunningnext = None
@@ -48,12 +49,12 @@ class ControlCenterWindow(gtk.Window):
         self.manager.connect('group-added', self._on_manager_group_added)
         self.manager.connect('group-removed', self._on_manager_group_removed)
         
-        self.connect('delete-event', gtk.main_quit)
-        self.connect('destroy-event', gtk.main_quit)
+        self.connect('delete-event', Gtk.main_quit)
+        self.connect('destroy-event', Gtk.main_quit)
         self.set_title(_("DVB Control Center"))
         self.set_default_size(800, 500)
         
-        self.vbox_outer = gtk.VBox()
+        self.vbox_outer = Gtk.VBox()
         self.vbox_outer.show()
         self.add(self.vbox_outer)
         
@@ -62,27 +63,27 @@ class ControlCenterWindow(gtk.Window):
         self.__create_menu()
         self.__create_toolbar()
         
-        self.hbox = gtk.HBox(spacing=6)
-        self.vbox_outer.pack_start(self.hbox)
+        self.hbox = Gtk.HBox(spacing=6)
+        self.vbox_outer.pack_start(self.hbox, True, True, 0)
         
-        self.hpaned = gtk.HPaned()
+        self.hpaned = Gtk.HPaned()
         self.hpaned.set_border_width(3)
         self.hpaned.set_position(175)
-        self.hbox.pack_start(self.hpaned)
+        self.hbox.pack_start(self.hpaned, True, True, 0)
         
-        self.vbox_left = gtk.VBox(spacing=6)
+        self.vbox_left = Gtk.VBox(spacing=6)
         self.hpaned.pack1(self.vbox_left)
 
-        self.devgroupslist = gtk.ListStore(str, int, gobject.TYPE_PYOBJECT)
+        self.devgroupslist = Gtk.ListStore(str, int, gobject.GObject)
         self.devgroupslist.connect("row-inserted", self._on_devgroupslist_inserted)
         
-        self.devgroupscombo = gtk.ComboBox(self.devgroupslist)
-        self.devgroupscombo.connect("changed", self._on_devgroupscombo_changed)
+        self.devgroupscombo = Gtk.ComboBox.new_with_model_and_entry(self.devgroupslist)
         
-        cell_adapter = gtk.CellRendererText()
-        self.devgroupscombo.pack_start(cell_adapter)
-        self.devgroupscombo.add_attribute(cell_adapter, "markup", 0)
-        self.vbox_left.pack_start(self.devgroupscombo, False)
+        cell_adapter = Gtk.CellRendererText()
+        self.devgroupscombo.pack_start(cell_adapter, True)
+        self.devgroupscombo.set_entry_text_column(0)
+        self.devgroupscombo.connect("changed", self._on_devgroupscombo_changed)
+        self.vbox_left.pack_start(self.devgroupscombo, False, True, 0)
         
         self.channelsstore = None
         
@@ -90,11 +91,11 @@ class ControlCenterWindow(gtk.Window):
         self.channelsview.set_headers_visible(False)
         self.channelsview.get_selection().connect("changed", self._on_channel_selected)
         
-        scrolledchannels = gtk.ScrolledWindow()
+        scrolledchannels = Gtk.ScrolledWindow()
         scrolledchannels.add(self.channelsview)
-        scrolledchannels.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        scrolledchannels.set_shadow_type(gtk.SHADOW_IN)
-        self.vbox_left.pack_start(scrolledchannels)
+        scrolledchannels.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        scrolledchannels.set_shadow_type(Gtk.ShadowType.IN)
+        self.vbox_left.pack_start(scrolledchannels, True, True, 0)
         
         self.schedulestore = None
                 
@@ -114,6 +115,8 @@ class ControlCenterWindow(gtk.Window):
             self.help_eventbox.set_markup(self.create_group_text)
         else:
             self._select_first_group()
+
+        Gtk.Window.set_default_icon_name("gnome-dvb-daemon")
       
     def __create_menu(self):
         ui = '''
@@ -143,14 +146,14 @@ class ControlCenterWindow(gtk.Window):
           </menu>
         </menubar>'''
 
-        uimanager = gtk.UIManager()
+        uimanager = Gtk.UIManager()
         
         # Add the accelerator group to the toplevel window
         accelgroup = uimanager.get_accel_group()
         self.add_accel_group(accelgroup)
         
         # Create actions
-        actiongroup = gtk.ActionGroup('Root')
+        actiongroup = Gtk.ActionGroup('Root')
         actiongroup.add_actions([
             ('Timers', None, _('_Recording schedule')),
             ('Edit', None, _('_Edit')),
@@ -160,30 +163,30 @@ class ControlCenterWindow(gtk.Window):
         # Add the actiongroup to the uimanager
         uimanager.insert_action_group(actiongroup, 0)
         
-        actiongroup = gtk.ActionGroup('Timers')
+        actiongroup = Gtk.ActionGroup('Timers')
         actiongroup.add_actions([
             ('EditTimers', None, _('_Manage'), '<Control>T',
              _('Manage recording schedule'), self._on_button_display_timers_clicked),
             ('Recordings', None, _('_Recordings'), '<Control>W',
              _('Manage recordings'), self._on_button_recordings_clicked),
-            ('Quit', gtk.STOCK_QUIT, _('_Quit'), None,
-             _('Quit the Program'), gtk.main_quit)])
+            ('Quit', Gtk.STOCK_QUIT, _('_Quit'), None,
+             _('Quit the Program'), Gtk.main_quit)])
         uimanager.insert_action_group(actiongroup, 1)
         
-        actiongroup = gtk.ActionGroup('Edit')
+        actiongroup = Gtk.ActionGroup('Edit')
         actiongroup.add_actions([
             ('EditChannelLists', None, _('_Channel Lists'), None,
              _('Edit channel lists'), self._on_edit_channellists_clicked),
-            ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences'), None,
+            ('Preferences', Gtk.STOCK_PREFERENCES, _('_Preferences'), None,
              _('Display preferences'), self._on_button_prefs_clicked),
         ])
         uimanager.insert_action_group(actiongroup, 2)
         
-        actiongroup = gtk.ActionGroup('View')
+        actiongroup = Gtk.ActionGroup('View')
         actiongroup.add_actions([
             ('WhatsOnNow', None, _("_What's on now"), None,
              _("See what's currently on and is coming next"), self._on_whats_on_now_clicked),
-            ('Refresh', gtk.STOCK_REFRESH, _('_Refresh'), '<Control>R',
+            ('Refresh', Gtk.STOCK_REFRESH, _('_Refresh'), '<Control>R',
              _('Refresh program guide'), self._on_refresh_clicked),
             ('PrevDay', None, _('_Previous Day'), '<Alt>Left',
              _('Go to previous day'), self._on_button_prev_day_clicked),
@@ -202,9 +205,9 @@ class ControlCenterWindow(gtk.Window):
         action.set_active(True)
         uimanager.insert_action_group(actiongroup, 3)
         
-        actiongroup = gtk.ActionGroup('Help')
+        actiongroup = Gtk.ActionGroup('Help')
         actiongroup.add_actions([
-            ('About', gtk.STOCK_ABOUT, _('_About'), None,
+            ('About', Gtk.STOCK_ABOUT, _('_About'), None,
              _('Display informations about the program'),
              self._on_about_clicked),
         ])
@@ -213,36 +216,37 @@ class ControlCenterWindow(gtk.Window):
         # Add a UI description
         uimanager.add_ui_from_string(ui)
 
-        timers_image = gtk.image_new_from_icon_name("stock_timer", gtk.ICON_SIZE_MENU)
+        timers_image = Gtk.Image.new_from_icon_name("appointment-soon", Gtk.IconSize.MENU)
         timers_image.show()
         
         self.timersitem = uimanager.get_widget('/MenuBar/Timers/EditTimers')
         self.timersitem.set_image(timers_image)
         self.timersitem.set_sensitive(False)
         
-        recordings_image = gtk.image_new_from_icon_name("video", gtk.ICON_SIZE_MENU)
+        recordings_image = Gtk.Image.new_from_icon_name("video", Gtk.IconSize.MENU)
         recordings_image.show()
         
         recordings = uimanager.get_widget('/MenuBar/Timers/Recordings')
         recordings.set_image(recordings_image)
         
-        whatson_image = gtk.image_new_from_stock(gtk.STOCK_INDEX, gtk.ICON_SIZE_MENU)
+        whatson_image = Gtk.Image.new_from_stock(Gtk.STOCK_INDEX, Gtk.IconSize.MENU)
         whatson_image.show()
         
-        whatons_item = uimanager.get_widget('/MenuBar/View/WhatsOnNow')
-        whatons_item.set_image(whatson_image)
+        self.whatons_item = uimanager.get_widget('/MenuBar/View/WhatsOnNow')
+        self.whatons_item.set_image(whatson_image)
+        self.whatons_item.set_sensitive(False)
         
         self.refresh_menuitem = uimanager.get_widget('/MenuBar/View/Refresh')
         self.refresh_menuitem.set_sensitive(False)
         
         self.prev_day_menuitem = uimanager.get_widget('/MenuBar/View/PrevDay')
-        prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_MENU)
+        prev_image = Gtk.Image.new_from_stock(Gtk.STOCK_GO_BACK, Gtk.IconSize.MENU)
         prev_image.show()
         self.prev_day_menuitem.set_image(prev_image)
         self.prev_day_menuitem.set_sensitive(False)
         
         self.next_day_menuitem = uimanager.get_widget('/MenuBar/View/NextDay')
-        next_image = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD, gtk.ICON_SIZE_MENU)
+        next_image = Gtk.Image.new_from_stock(Gtk.STOCK_GO_FORWARD, Gtk.IconSize.MENU)
         next_image.show()
         self.next_day_menuitem.set_image(next_image)
         self.next_day_menuitem.set_sensitive(False)
@@ -250,17 +254,17 @@ class ControlCenterWindow(gtk.Window):
         # Create a MenuBar
         menubar = uimanager.get_widget('/MenuBar')
         menubar.show()
-        self.vbox_outer.pack_start(menubar, False)
+        self.vbox_outer.pack_start(menubar, False, True, 0)
         
     def __create_toolbar(self):
-        self.toolbar = gtk.Toolbar()
+        self.toolbar = Gtk.Toolbar()
         self.toolbar.show()
-        self.vbox_outer.pack_start(self.toolbar, False)
+        self.vbox_outer.pack_start(self.toolbar, False, True, 0)
 
-        timers_image = gtk.image_new_from_icon_name("stock_timer", gtk.ICON_SIZE_MENU)
+        timers_image = Gtk.Image.new_from_icon_name("appointment-soon", Gtk.IconSize.MENU)
         timers_image.show()
         
-        self.button_display_timers = gtk.ToolButton(icon_widget=timers_image, label=_("Recording schedule"))
+        self.button_display_timers = Gtk.ToolButton(icon_widget=timers_image, label=_("Recording schedule"))
         self.button_display_timers.set_is_important(True)
         self.button_display_timers.set_sensitive(False)
         self.button_display_timers.connect("clicked", self._on_button_display_timers_clicked)
@@ -268,46 +272,47 @@ class ControlCenterWindow(gtk.Window):
         self.button_display_timers.show()
         self.toolbar.insert(self.button_display_timers, 0)
         
-        recordings_image = gtk.image_new_from_icon_name("video", gtk.ICON_SIZE_MENU)
+        recordings_image = Gtk.Image.new_from_icon_name("video", Gtk.IconSize.MENU)
         recordings_image.show()
         
-        button_recordings = gtk.ToolButton(icon_widget=recordings_image, label=_("Recordings"))
+        button_recordings = Gtk.ToolButton(icon_widget=recordings_image, label=_("Recordings"))
         button_recordings.set_is_important(True)
         button_recordings.connect("clicked", self._on_button_recordings_clicked)
         button_recordings.show()
         self.toolbar.insert(button_recordings, 1)
         
-        whatson_image = gtk.image_new_from_stock(gtk.STOCK_INDEX, gtk.ICON_SIZE_LARGE_TOOLBAR)
+        whatson_image = Gtk.Image.new_from_stock(Gtk.STOCK_INDEX, Gtk.IconSize.LARGE_TOOLBAR)
         whatson_image.show()
         
-        button_whatson = gtk.ToolButton(icon_widget=whatson_image, label=_("What's on now"))
-        button_whatson.set_is_important(True)
-        button_whatson.connect("clicked", self._on_whats_on_now_clicked)
-        button_whatson.show()
-        self.toolbar.insert(button_whatson, 2)
+        self.button_whatson = Gtk.ToolButton(icon_widget=whatson_image, label=_("What's on now"))
+        self.button_whatson.set_is_important(True)
+        self.button_whatson.set_sensitive(False)
+        self.button_whatson.connect("clicked", self._on_whats_on_now_clicked)
+        self.button_whatson.show()
+        self.toolbar.insert(self.button_whatson, 2)
          
-        sep = gtk.SeparatorToolItem()
+        sep = Gtk.SeparatorToolItem()
         sep.show()
         self.toolbar.insert(sep, 3)
         
-        self.refresh_button = gtk.ToolButton(gtk.STOCK_REFRESH)
+        self.refresh_button = Gtk.ToolButton.new_from_stock(Gtk.STOCK_REFRESH)
         self.refresh_button.connect("clicked", self._on_refresh_clicked)
         self.refresh_button.set_tooltip_markup(_("Refresh program guide"))        
         self.refresh_button.show()
         self.toolbar.insert(self.refresh_button, 4)
         
-        prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_LARGE_TOOLBAR)
+        prev_image = Gtk.Image.new_from_stock(Gtk.STOCK_GO_BACK, Gtk.IconSize.LARGE_TOOLBAR)
         prev_image.show()
-        self.button_prev_day = gtk.ToolButton(icon_widget=prev_image, label=_("Previous Day"))
+        self.button_prev_day = Gtk.ToolButton(icon_widget=prev_image, label=_("Previous Day"))
         self.button_prev_day.connect("clicked", self._on_button_prev_day_clicked)
         self.button_prev_day.set_tooltip_markup(_("Go to previous day"))
         self.button_prev_day.set_sensitive(False)
         self.button_prev_day.show()
         self.toolbar.insert(self.button_prev_day, 5)
         
-        next_image = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD, gtk.ICON_SIZE_LARGE_TOOLBAR)
+        next_image = Gtk.Image.new_from_stock(Gtk.STOCK_GO_FORWARD, Gtk.IconSize.LARGE_TOOLBAR)
         next_image.show()
-        self.button_next_day = gtk.ToolButton(icon_widget=next_image, label=_("Next Day"))
+        self.button_next_day = Gtk.ToolButton(icon_widget=next_image, label=_("Next Day"))
         self.button_next_day.connect("clicked", self._on_button_next_day_clicked)
         self.button_next_day.set_tooltip_markup(_("Go to next day"))
         self.button_next_day.set_sensitive(False)
@@ -319,7 +324,7 @@ class ControlCenterWindow(gtk.Window):
             for group in groups:
                 self._append_group(group)
             self.check_single_group_mode()
-        self.manager.get_registered_device_groups(reply_handler=append_groups)
+        self.manager.get_registered_device_groups(result_handler=append_groups)
         
     def check_single_group_mode(self):
         val = len(self.devgroupslist) == 1
@@ -400,6 +405,7 @@ class ControlCenterWindow(gtk.Window):
         group = self._get_selected_group()
         if group != None:
             self._set_timers_sensitive(True)
+            self._set_whatson_sensitive(True)
             
             self.channelsstore = ChannelsStore(group)
             self.channelsview.set_model(self.channelsstore)
@@ -455,9 +461,9 @@ class ControlCenterWindow(gtk.Window):
         
         self.runningnextstore = RunningNextStore(group)
         
-        self.scrolledrunningnext = gtk.ScrolledWindow()
-        self.scrolledrunningnext.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        self.scrolledrunningnext.set_shadow_type(gtk.SHADOW_IN)
+        self.scrolledrunningnext = Gtk.ScrolledWindow()
+        self.scrolledrunningnext.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        self.scrolledrunningnext.set_shadow_type(Gtk.ShadowType.IN)
         self.scrolledrunningnext.show()
         
         self.runningnextview = RunningNextView(self.runningnextstore)
@@ -486,19 +492,23 @@ class ControlCenterWindow(gtk.Window):
     def _set_refresh_sensitive(self, val):
         self.refresh_button.set_sensitive(val) 
         self.refresh_menuitem.set_sensitive(val)
-       
+
+    def _set_whatson_sensitive(self, val):
+        self.whatons_item.set_sensitive(val)
+        self.button_whatson.set_sensitive(val)
+
     def _on_event_selected(self, treeview, event):
-        if event.type == gtk.gdk._2BUTTON_PRESS:
+        if event.type == getattr(Gdk.EventType, "2BUTTON_PRESS"):
             model, aiter = treeview.get_selection().get_selected()
             if aiter != None:
-                dialog = gtk.MessageDialog(parent=self,
-                    flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
-                    type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_YES_NO)
+                dialog = Gtk.MessageDialog(parent=self,
+                    flags=Gtk.DialogFlags.MODAL|Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                    type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
                 dialog.set_markup (
                     "<big><span weight=\"bold\">%s</span></big>" % _("Schedule recording for the selected event?"))
                 rec_id = -1
                 success = True
-                if dialog.run() == gtk.RESPONSE_YES:
+                if dialog.run() == Gtk.ResponseType.YES:
                     event_id = model[aiter][model.COL_EVENT_ID]
                     group = self._get_selected_group()
                     channel_sid = self._get_selected_channel_sid()
@@ -511,20 +521,20 @@ class ControlCenterWindow(gtk.Window):
                     dialog.run()
                     dialog.destroy()
         
-    def _on_button_display_timers_clicked(self, button):
+    def _on_button_display_timers_clicked(self, button, user_data=None):
         group = self._get_selected_group()
         if group != None:
             edit = EditTimersDialog(group, self)
             edit.run()
             edit.destroy()
             
-    def _on_whats_on_now_clicked(self, button):
+    def _on_whats_on_now_clicked(self, button, user_data=None):
         self._reset_schedule_view()
             
-    def _on_refresh_clicked(self, button):
+    def _on_refresh_clicked(self, button, user_data=None):
         self.schedulestore.reload_all()
    
-    def _on_button_prev_day_clicked(self, button):
+    def _on_button_prev_day_clicked(self, button, user_data=None):
         if self.schedulestore != None:
             model, aiter = self.scheduleview.get_selection().get_selected()
             if aiter == None:
@@ -538,9 +548,9 @@ class ControlCenterWindow(gtk.Window):
                 self._set_next_day_sensitive(True)
                 day_path = model.get_path(day_iter)
                 self.scheduleview.scroll_to_cell(day_path, use_align=True)
-                self.scheduleview.set_cursor(day_path)
+                self.scheduleview.set_cursor(day_path, None, False)
             
-    def _on_button_next_day_clicked(self, button):
+    def _on_button_next_day_clicked(self, button, user_data=None):
         if self.schedulestore != None:
             model, aiter = self.scheduleview.get_selection().get_selected()
             if aiter == None:
@@ -554,33 +564,33 @@ class ControlCenterWindow(gtk.Window):
                 self._set_previous_day_sensitive(True)
                 day_path = model.get_path(day_iter)
                 self.scheduleview.scroll_to_cell(day_path, use_align=True)
-                self.scheduleview.set_cursor(day_path)
+                self.scheduleview.set_cursor(day_path, None, False)
     
-    def _on_button_prefs_clicked(self, button):
+    def _on_button_prefs_clicked(self, button, user_data=None):
         prefs = Preferences(self.manager, self)
         prefs.show()
         
-    def _on_button_recordings_clicked(self, button):
+    def _on_button_recordings_clicked(self, button, user_data=None):
         dialog = RecordingsDialog(self)
         dialog.run()
         dialog.destroy()
         
-    def _on_view_channels_clicked(self, action):
+    def _on_view_channels_clicked(self, action, user_data=None):
         if self.vbox_left:
             if action.get_active():
                 self.vbox_left.show()
             else:
                 self.vbox_left.hide()
         
-    def _on_view_toolbar_clicked(self, action):
+    def _on_view_toolbar_clicked(self, action, user_data=None):
         if self.toolbar:
             if action.get_active():
                 self.toolbar.show()
             else:
                 self.toolbar.hide()
 
-    def _on_about_clicked(self, action):
-        about = gtk.AboutDialog()
+    def _on_about_clicked(self, action, user_data=None):
+        about = Gtk.AboutDialog()
         about.set_transient_for(self)
         #translators: These appear in the About dialog, usual format applies.
         about.set_translator_credits( _("translator-credits") )
@@ -592,7 +602,7 @@ class ControlCenterWindow(gtk.Window):
         about.run()
         about.destroy()
         
-    def _on_edit_channellists_clicked(self, action):
+    def _on_edit_channellists_clicked(self, action, user_data=None):
         dialog = ChannelListEditorDialog(self.manager, parent=self)
         dialog.run()
         dialog.destroy()
