@@ -17,9 +17,8 @@
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
 import gobject
-import glib
 import gnomedvb
-import gtk
+from gi.repository import Gtk
 import os.path
 from gettext import gettext as _
 from gnomedvb.ui.wizard import DVB_TYPE_TO_DESC
@@ -46,7 +45,7 @@ class SetupDevicePage(BasePage):
         return _("Configuring device")
         
     def get_page_type(self):
-        return gtk.ASSISTANT_PAGE_PROGRESS
+        return Gtk.AssistantPageType.PROGRESS
   
     def set_scanner(self, scanner):
         self.__scanner = scanner
@@ -69,32 +68,32 @@ class SetupDevicePage(BasePage):
     def run(self, create_group):
         self.show_progressbar()
         
-        def reply_handler(success):
+        def reply_handler(proxy, success, user_data):
             self.destroy_progressbar()
             self.__success = True
             self.emit("finished", True)
         
         existing_group = self.get_existing_group_of_same_type()
         if existing_group == None:
-            self.create_group_automatically(reply_handler=reply_handler,
+            self.create_group_automatically(result_handler=reply_handler,
                 error_handler=gnomedvb.global_error_handler)
         else:
-            self.add_to_group(existing_group, reply_handler=reply_handler,
+            self.add_to_group(existing_group, result_handler=reply_handler,
                 error_handler=gnomedvb.global_error_handler)
          
     def show_progressbar(self):
         # From parent
         self._label.hide()
 
-        self._progressbar = gtk.ProgressBar()
+        self._progressbar = Gtk.ProgressBar()
         self._progressbar.set_text(_("Configuring device"))
         self._progressbar.set_fraction(0.1)
         self._progressbar.show()
-        self.pack_start(self._progressbar, False)
-        self._progressbar_timer = glib.timeout_add(100, self.progressbar_pulse)
+        self.pack_start(self._progressbar, False, True, 0)
+        self._progressbar_timer = gobject.timeout_add(100, self.progressbar_pulse)
         
     def destroy_progressbar(self):
-        glib.source_remove(self._progressbar_timer)
+        gobject.source_remove(self._progressbar_timer)
         self._progressbar_timer = None
         self._progressbar.destroy()
 
@@ -112,15 +111,15 @@ class SetupDevicePage(BasePage):
                 break
         return existing_group
 
-    def create_group_automatically(self, reply_handler, error_handler):
-        def write_channels_handler(success):
+    def create_group_automatically(self, result_handler, error_handler):
+        def write_channels_handler(proxy, success, user_data):
             if success:
                 recordings_dir = gnomedvb.get_default_recordings_dir()
                 name = "%s %s" % (DVB_TYPE_TO_DESC[self.__adapter_info["type"]], _("TV"))
                 self.__model.add_device_to_new_group(self.__adapter_info['adapter'],
                                 self.__adapter_info['frontend'], channels_file,
                                 recordings_dir, name,
-                                reply_handler=reply_handler, error_handler=error_handler)
+                                result_handler=result_handler, error_handler=error_handler)
             else:
                 self.show_error()
 
@@ -134,12 +133,12 @@ class SetupDevicePage(BasePage):
                 "channels_%s.conf" % self.__adapter_info["type"])
             
             self.__scanner.write_channels_to_file(self.__channels, channels_file,
-                reply_handler=write_channels_handler, error_handler=error_handler)
+                result_handler=write_channels_handler, error_handler=error_handler)
                         
-    def add_to_group(self, group, reply_handler, error_handler):
+    def add_to_group(self, group, result_handler, error_handler):
         self.__summary = _('The device has been added to the group %s.') % group['name']
         group.add_device(self.__adapter_info['adapter'],
-            self.__adapter_info['frontend'], reply_handler=reply_handler,
+            self.__adapter_info['frontend'], result_handler=result_handler,
             error_handler=error_handler)
 
     def show_error(self):
