@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2008-2010 Sebastian Pölsterl
+# Copyright (C) 2008-2011 Sebastian Pölsterl
 #
 # This file is part of GNOME DVB Daemon.
 #
@@ -16,22 +16,20 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-import dbus
-import dbus.glib
-import pygtk
-pygtk.require("2.0")
-from glib import GError
-import glib
-import gtk
+import gettext
+import gnomedvb
+import gobject
 import os
 import os.path
-import pygst
-pygst.require("0.10")
-import totem
-import gnomedvb
 import sys
+
+from gi.repository import Gdk
+from gi.repository import Gio
+from gi.repository import Gtk
+from gi.repository import Peas
+from gi.repository import Totem
 from cgi import escape
-import gettext
+from gobject import GError
 
 from gnomedvb import global_error_handler
 from gnomedvb.DVBModel import DVBModel
@@ -56,11 +54,18 @@ def spawn_on_screen(argv, screen, flags=0):
     def set_environment (display):
         os.environ["DISPLAY"] = display
 
-    return glib.spawn_async(argv,
+    return gobject.spawn_async(argv,
 		      flags=flags,
 		      child_setup=set_environment,
 		      user_data=screen.make_display_name())
 
+def _get_dbus_proxy():
+    return Gio.DBusProxy.new_for_bus_sync(Gio.BusType.SESSION,
+            Gio.DBusProxyFlags.NONE, None,
+            "org.freedesktop.DBus",
+            "/org/freedesktop/DBus",
+            "org.freedesktop.DBus", None)
+
 class DvbSetup:
 
     (MISSING,
@@ -91,11 +96,11 @@ class DvbSetup:
         argv = [setup_cmd, "--transient-for=%d" % xid]
 
         pid = spawn_on_screen (argv, screen,
-            flags=glib.SPAWN_FILE_AND_ARGV_ZERO | glib.SPAWN_DO_NOT_REAP_CHILD)[0]
+            flags=gobject.SpawnFlags.FILE_AND_ARGV_ZERO | gobject.SpawnFlags.DO_NOT_REAP_CHILD)[0]
 
         self._in_progress = True
 
-        glib.child_watch_add (pid, self._child_watch_func,
+        gobject.child_watch_add (pid, self._child_watch_func,
             (callback, user_data))
 
         return self.STARTED_OK
@@ -127,12 +132,7 @@ class DvbSetup:
         return None
 
     def _dbus_service_available(self, name):
-        bus = dbus.SessionBus()
-        # Get proxy object
-        proxy = bus.get_object("org.freedesktop.DBus",
-            "/org/freedesktop/DBus")
-        # Apply the correct interace to the proxy object
-        dbusobj = dbus.Interface(proxy, "org.freedesktop.DBus")
+	dbusobj = _get_dbus_proxy()
 
         for iname in dbusobj.ListNames():
             if iname == name:
@@ -145,23 +145,24 @@ class DvbSetup:
         return False
 
 
-class ScheduleDialog(gtk.Dialog):
+class ScheduleDialog(Gtk.Dialog):
 
     def __init__(self, group, sid, parent=None):
-        gtk.Dialog.__init__(self, title=_("Program Guide"),
+        Gtk.Dialog.__init__(self, title=_("Program Guide"),
             parent=parent,
-            flags=gtk.DIALOG_DESTROY_WITH_PARENT,
-            buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
+            flags=Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE))
             
         self._group = group
         self._sid = sid
             
         self.set_default_size(640, 380)
-        self.vbox.set_spacing(6)
+        content_area = self.get_content_area()
+        content_area.set_spacing(6)
             
         self.schedulepaned = SchedulePaned()
         self.schedulepaned.show()
-        self.vbox.pack_start(self.schedulepaned)
+        content_area.pack_start(self.schedulepaned, True, True, 0)
         
         self.scheduleview = self.schedulepaned.get_treeview()
         self.scheduleview.connect("button-press-event", self._on_event_selected)
@@ -170,51 +171,56 @@ class ScheduleDialog(gtk.Dialog):
         self.scheduleview.set_model(self.schedulestore)
     
     def _on_event_selected(self, treeview, event):
-        if event.type == gtk.gdk._2BUTTON_PRESS:
+        if event.type == Gdk.EventType._2BUTTON_PRESS:
             model, aiter = treeview.get_selection().get_selected()
             if aiter != None:
-                dialog = gtk.MessageDialog(parent=self,
-                    flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-                    type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_YES_NO)
+                dialog = Gtk.MessageDialog(parent=self,
+                    flags=Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                    type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
                 dialog.set_markup ("<big><span weight=\"bold\">%s</span></big>" % _("Schedule recording for the selected event?"))
                 response = dialog.run()
-                if response == gtk.RESPONSE_YES:
+                if response == Gtk.ResponseType.YES:
                     event_id = model[aiter][model.COL_EVENT_ID]
                     recorder = self._group.get_recorder()
                     rec_id, success = recorder.add_timer_for_epg_event(event_id, self._sid)
                 dialog.destroy()
                 
-                if response == gtk.RESPONSE_YES and not success:
+                if response == Gtk.ResponseType.YES and not success:
                     dialog = TimerFailureDialog(self)
                     dialog.run()
                     dialog.destroy()
 
-class RunningNextDialog(gtk.Dialog):
+class RunningNextDialog(Gtk.Dialog):
 
     def __init__(self, group, parent=None):
-        gtk.Dialog.__init__(self, title=_("Program Guide"),
+        Gtk.Dialog.__init__(self, title=_("Program Guide"),
             parent=parent,
-            flags=gtk.DIALOG_DESTROY_WITH_PARENT,
-            buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
+            flags=Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE))
             
         self._group = group
         
         self.set_default_size(640, 380)
-        self.vbox.set_spacing(6)
+        content_area = self.get_content_area()
+        content_area.set_spacing(6)
         
         self.schedule = RunningNextStore(self._group)
         self.scheduleview = RunningNextView(self.schedule)
         self.scheduleview.show()
         
-        self.scrolledschedule = gtk.ScrolledWindow()
+        self.scrolledschedule = Gtk.ScrolledWindow()
         self.scrolledschedule.add(self.scheduleview)
-        self.scrolledschedule.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        self.scrolledschedule.set_shadow_type(gtk.SHADOW_IN)
-        self.vbox.pack_start(self.scrolledschedule)
+        self.scrolledschedule.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        self.scrolledschedule.set_shadow_type(Gtk.ShadowType.IN)
+        content_area.pack_start(self.scrolledschedule, True, True, 0)
         self.scrolledschedule.show()
 
 
-class DVBDaemonPlugin(totem.Plugin):
+class DVBDaemonPlugin(gobject.GObject, Peas.Activatable):
+
+    __gtype_name__ = 'DVBDaemonPlugin'
+
+    object = gobject.property(type = gobject.GObject)
 
     REC_GROUP_ID = -1
     
@@ -233,8 +239,6 @@ class DVBDaemonPlugin(totem.Plugin):
      ORDER_BY_GROUP_ID,) = range(2)
 
     def __init__ (self):
-        totem.Plugin.__init__(self)
-        
         self.totem_object = None
         self.channels = None
         self.channels_view = None
@@ -253,37 +257,32 @@ class DVBDaemonPlugin(totem.Plugin):
         self._size = 0
         self._loaded_groups = 0
 
-    def activate (self, totem_object):
-        self.totem_object = totem_object
-
+    def do_activate (self):
         gettext.bindtextdomain('gnome-dvb-daemon')
 
         self.monitor_bus()
 
         try:
             self.construct()
-        except dbus.DBusException:
-            print >> sys.stderr, "Failed activating DVB DBus service"
+        except Exception, e:
+            print >> sys.stderr, "Failed activating DVB DBus service", str(e)
             return
 
     def monitor_bus(self):
-        bus = dbus.SessionBus()
-        # Get proxy object
-        proxy = bus.get_object("org.freedesktop.DBus",
-            "/org/freedesktop/DBus")
-        # Apply the correct interace to the proxy object
-        dbusobj = dbus.Interface(proxy, "org.freedesktop.DBus")
+        dbusobj = _get_dbus_proxy()
+        dbusobj.connect("g-signal", self.on_dbus_signal)
 
-        dbusobj.connect_to_signal("NameOwnerChanged", self.on_dbus_owner_changed)
-
-    def on_dbus_owner_changed(self, name, old_owner, new_owner):
-        if name == DBUS_DVB_SERVICE:
-            if old_owner == "":
-                self.construct()
-            elif new_owner == "":
-                self.deactivate(self.totem_object)
+    def on_dbus_signal(self, proxy, sender_name, signal_name, params):
+        if signal_name == "NameOwnerChanged":
+            name, old_owner, new_owner = params.unpack()
+            if name == DBUS_DVB_SERVICE:
+                if old_owner == "":
+                    self.construct()
+                elif new_owner == "":
+                    self.deactivate()
 
     def construct(self):
+        self.totem_object = self.object
         self.manager = DVBModel()
 
         self.setup = DvbSetup()
@@ -297,18 +296,24 @@ class DVBDaemonPlugin(totem.Plugin):
             self._setup_sidebar()
             self._setup_menu()
 
-            # Add recordings
-            self.rec_iter = self.channels.append(None, [self.REC_GROUP_ID, _("Recordings"), 0, None])
-            self.recstore = gnomedvb.DVBRecordingsStoreClient()
-            self.recstore.connect("changed", self._on_recstore_changed)
-            add_rec = lambda recs: [self._add_recording(rid) for rid in recs]
-            self.recstore.get_recordings(reply_handler=add_rec, error_handler=global_error_handler)
+            self._get_and_add_recordings()
             
             self.totem_object.add_sidebar_page ("dvb-daemon", _("Digital TV"), self.sidebar)
             self.sidebar.show_all()
-        
+
+    def _get_and_add_recordings(self):
+        # Add recordings
+        self.rec_iter = self.channels.append(None)
+        self.channels[self.rec_iter][ChannelsTreeStore.COL_GROUP_ID] = self.REC_GROUP_ID
+        self.channels[self.rec_iter][ChannelsTreeStore.COL_NAME] = _("Recordings")
+
+        self.recstore = gnomedvb.DVBRecordingsStoreClient()
+        self.recstore.connect("changed", self._on_recstore_changed)
+        add_rec = lambda p,recs,u: [self._add_recording(rid) for rid in recs]
+        self.recstore.get_recordings(result_handler=add_rec, error_handler=global_error_handler)
+
     def _setup_sidebar(self):
-        self.sidebar = gtk.VBox(spacing=6)
+        self.sidebar = Gtk.VBox(spacing=6)
         
         self.channels = ChannelsTreeStore()
         self.channels.connect("loading-finished", self._on_group_loaded)
@@ -317,39 +322,39 @@ class DVBDaemonPlugin(totem.Plugin):
         self.channels_view.connect("button-press-event", self._on_channel_selected)
         self.channels_view.get_selection().connect("changed", self._on_selection_changed)
         
-        self.scrolledchannels = gtk.ScrolledWindow()
-        self.scrolledchannels.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        self.scrolledchannels.set_shadow_type(gtk.SHADOW_ETCHED_IN)
+        self.scrolledchannels = Gtk.ScrolledWindow()
+        self.scrolledchannels.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        self.scrolledchannels.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
         self.scrolledchannels.add(self.channels_view)
-        self.sidebar.pack_start(self.scrolledchannels)
+        self.sidebar.pack_start(self.scrolledchannels, True, True, 0)
         
-        buttonbox = gtk.HButtonBox()
+        buttonbox = Gtk.HButtonBox()
         buttonbox.set_spacing(6)
-        self.sidebar.pack_start(buttonbox, False)
+        self.sidebar.pack_start(buttonbox, False, True, 0)
         
-        self.whatson_button = gtk.Button(label=_("What's on now"))
-        self.whatson_button.set_image(gtk.image_new_from_stock(gtk.STOCK_INDEX, gtk.ICON_SIZE_BUTTON))
+        self.whatson_button = Gtk.Button(label=_("What's on now"))
+        self.whatson_button.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_INDEX, Gtk.IconSize.BUTTON))
         self.whatson_button.connect('clicked', self._on_action_whats_on_now)
-        buttonbox.pack_start(self.whatson_button)
+        buttonbox.pack_start(self.whatson_button, True, True, 0)
         self.whatson_button.set_sensitive(False)
         
-        self.epg_button = gtk.Button(label=_('Program Guide'))
+        self.epg_button = Gtk.Button(label=_('Program Guide'))
         self.epg_button.connect('clicked', self._on_action_epg)
         self.epg_button.set_sensitive(False)
-        buttonbox.pack_start(self.epg_button)
+        buttonbox.pack_start(self.epg_button, True, True, 0)
         
     def _setup_menu(self):
         uimanager = self.totem_object.get_ui_manager()
         
         # Create actions
-        actiongroup = gtk.ActionGroup('dvb')
+        actiongroup = Gtk.ActionGroup('dvb')
         actiongroup.add_actions([
             ('dvbdevice', None, _('Watch TV'), None, None, self._on_play_dvb_activated),
             ('dvb-menu', None, _('Digital _TV')),
             ('dvb-timers', None, _('_Recording schedule'), None, None, self._on_action_timers),
             ('dvb-epg', None, _('_Program Guide'), None, None, self._on_action_epg),
-            ('dvb-whatson', gtk.STOCK_INDEX, _("What's on now"), None, None, self._on_action_whats_on_now),
-            ('dvb-preferences', gtk.STOCK_PREFERENCES, _('Digital TV Preferences'), None, None, self._on_action_preferences),
+            ('dvb-whatson', Gtk.STOCK_INDEX, _("What's on now"), None, None, self._on_action_whats_on_now),
+            ('dvb-preferences', Gtk.STOCK_PREFERENCES, _('Digital TV Preferences'), None, None, self._on_action_preferences),
             ('dvb-delete-recording', None, _('_Delete'), None, None, self._on_action_delete),
             ('dvb-detail-recording', None, _('D_etails'), None, None, self._on_action_details),
             ('dvb-order-channels', None, _('_Order channels')),
@@ -370,69 +375,69 @@ class DVBDaemonPlugin(totem.Plugin):
         # Movie menu
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/movie/devices-placeholder',
-            'dvbdevice', 'dvbdevice', gtk.UI_MANAGER_MENUITEM, False)
+            'dvbdevice', 'dvbdevice', Gtk.UIManagerItemType.MENUITEM, False)
 
         # Edit menu
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/edit/plugins', 'dvb-timers', 'dvb-timers',
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
         
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/edit/plugins', 'dvb-preferences', 'dvb-preferences',
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
             
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/edit/plugins', 'dvb-sep-1', None,
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
         
         # View menu
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/sidebar', 'dvb-whatson', 'dvb-whatson',
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
         
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/sidebar', 'dvb-epg', 'dvb-epg',
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
         
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/sidebar', 'dvb-sep-2', None,
-            gtk.UI_MANAGER_AUTO, True)
+            Gtk.UIManagerItemType.AUTO, True)
 
         # Order by menu
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/show-controls', 'dvb-order-channels',
-            'dvb-order-channels', gtk.UI_MANAGER_MENU, False)
+            'dvb-order-channels', Gtk.UIManagerItemType.MENU, False)
             
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/dvb-order-channels',
-            'dvb-order-by-name', 'dvb-order-by-name', gtk.UI_MANAGER_AUTO, False)
+            'dvb-order-by-name', 'dvb-order-by-name', Gtk.UIManagerItemType.AUTO, False)
             
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/dvb-order-channels',
-            'dvb-order-by-group', 'dvb-order-by-group', gtk.UI_MANAGER_AUTO, False)
+            'dvb-order-by-group', 'dvb-order-by-group', Gtk.UIManagerItemType.AUTO, False)
         
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/dvb-order-channels', 'dvb-sep-3', None,
-            gtk.UI_MANAGER_AUTO, False)
+            Gtk.UIManagerItemType.AUTO, False)
             
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/dvb-order-channels',
-            'dvb-order-reverse', 'dvb-order-reverse', gtk.UI_MANAGER_AUTO, False)
+            'dvb-order-reverse', 'dvb-order-reverse', Gtk.UIManagerItemType.AUTO, False)
         
         merge_id = uimanager.new_merge_id()
         uimanager.add_ui(merge_id, '/tmw-menubar/view/show-controls', 'dvb-sep-4', None,
-            gtk.UI_MANAGER_AUTO, False)
+            Gtk.UIManagerItemType.AUTO, False)
         
         self.popup_menu = uimanager.get_widget('/dvb-popup')
         self.popup_recordings = uimanager.get_widget('/dvb-recording-popup')
 
-        totemtv_image = gtk.image_new_from_icon_name("totem-tv", gtk.ICON_SIZE_MENU)
+        totemtv_image = Gtk.Image.new_from_icon_name("totem-tv", Gtk.IconSize.MENU)
         totemtv_image.show()
 
         watch_item = uimanager.get_widget('/tmw-menubar/movie/devices-placeholder/dvbdevice')
         watch_item.set_image(totemtv_image)
         
-        timers_image = gtk.image_new_from_icon_name("stock_timer", gtk.ICON_SIZE_MENU)
+        timers_image = Gtk.Image.new_from_icon_name("stock_timer", Gtk.IconSize.MENU)
         timers_image.show()
         
         self.timers_item = uimanager.get_widget('/tmw-menubar/edit/dvb-timers')
@@ -448,7 +453,7 @@ class DVBDaemonPlugin(totem.Plugin):
     def _configure_mode(self):
         if self._size == 1:
             # Activate single group mode
-            root_iter = self.channels.get_iter_root()
+            root_iter = self.channels.get_iter_first()
             group_iter = self.channels.iter_next(root_iter)
             self.single_group = self.channels[group_iter][self.channels.COL_GROUP]
             self._enable_single_group_mode(True)
@@ -471,7 +476,7 @@ class DVBDaemonPlugin(totem.Plugin):
         else:
             return (model[aiter][model.COL_GROUP], model[aiter][model.COL_SID],)
 
-    def _on_action_timers(self, action):
+    def _on_action_timers(self, action, user_date=None):
         group = self._get_selected_group_and_channel()[0]
         if group == None:
             group = self.single_group
@@ -480,7 +485,7 @@ class DVBDaemonPlugin(totem.Plugin):
             edit.run()
             edit.destroy()
 
-    def _on_action_epg(self, action):
+    def _on_action_epg(self, action, user_date=None):
         group, sid = self._get_selected_group_and_channel()
         if group == None:
             group = self.single_group
@@ -492,7 +497,7 @@ class DVBDaemonPlugin(totem.Plugin):
             dialog.connect("response", lambda d, resp: d.destroy())
             dialog.show()
             
-    def _on_action_whats_on_now(self, action):
+    def _on_action_whats_on_now(self, action, user_date=None):
         group, sid = self._get_selected_group_and_channel()
         if group == None:
             group = self.single_group
@@ -501,25 +506,25 @@ class DVBDaemonPlugin(totem.Plugin):
             dialog.connect("response", lambda d, resp: d.destroy())
             dialog.show()
     
-    def _on_action_preferences(self, action):
+    def _on_action_preferences(self, action, user_date=None):
         prefs = Preferences(self.manager, self.totem_object.get_main_window())
         prefs.show()
         
-    def _on_action_delete(self, action):
+    def _on_action_delete(self, action, user_date=None):
         model, aiter = self.channels_view.get_selection().get_selected()
         if aiter != None:
-            dialog = gtk.MessageDialog(parent=self.totem_object.get_main_window(),
-                    flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
-                    type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_YES_NO)
+            dialog = Gtk.MessageDialog(parent=self.totem_object.get_main_window(),
+                    flags=Gtk.DialogFlags.MODAL|Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                    type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
             dialog.set_markup("<big><span weight=\"bold\">%s</span></big>" % _("Delete selected recording?"))
             response = dialog.run()
             dialog.destroy()
-            if response == gtk.RESPONSE_YES:
+            if response == Gtk.ResponseType.YES:
                 self.recstore.delete(model[aiter][model.COL_SID],
-                    reply_handler=self._delete_callback,
+                    result_handler=self._delete_callback,
                     error_handler=global_error_handler)
         
-    def _on_action_details(self, action):
+    def _on_action_details(self, action, user_date=None):
         model, aiter = self.channels_view.get_selection().get_selected()
         if aiter != None:
             rec_id = model[aiter][model.COL_SID]
@@ -527,25 +532,29 @@ class DVBDaemonPlugin(totem.Plugin):
             dialog.run()
             dialog.destroy()
     
-    def deactivate (self, totem_object):
-        totem_object.remove_sidebar_page ("dvb-daemon")
-        self.totem_object = None
+    def do_deactivate (self):
+        if self.totem_object != None:
+            self.totem_object.remove_sidebar_page ("dvb-daemon")
         
     def _on_channel_selected(self, treeview, event):
-        if event.type == gtk.gdk._2BUTTON_PRESS:
+        if event.type == Gdk.EventType._2BUTTON_PRESS:
             # double click
             model, aiter = treeview.get_selection().get_selected()
             if aiter != None:
                 group_id = model[aiter][model.COL_GROUP_ID]
                 sid = model[aiter][model.COL_SID]
+                # Skip section headers
+                if sid == 0L:
+                    return
+
                 if group_id == self.REC_GROUP_ID:
                     url, success = self.recstore.get_location(sid)
                 else:
                     group = gnomedvb.DVBManagerClient().get_device_group(group_id)
                     channellist = group.get_channel_list()
                     url, success = channellist.get_channel_url(sid)
-                self.totem_object.action_remote(totem.REMOTE_COMMAND_REPLACE, url)
-                self.totem_object.action_remote(totem.REMOTE_COMMAND_PLAY, url)
+                self.totem_object.action_remote(Totem.RemoteCommand.REPLACE, url)
+                self.totem_object.action_remote(Totem.RemoteCommand.PLAY, url)
         elif event.button == 3:
             # right click button
             x = int(event.x)
@@ -562,9 +571,9 @@ class DVBDaemonPlugin(totem.Plugin):
                     # We are in the recordings section
                     if model.iter_parent(aiter) != None:
                         # A child is selected
-                        self.popup_recordings.popup(None, None, None, event.button, time)
+                        self.popup_recordings.popup(None, None, None, None, event.button, time)
                 else:
-                    self.popup_menu.popup(None, None, None, event.button, time)
+                    self.popup_menu.popup(None, None, None, None, event.button, time)
         
     def _on_selection_changed(self, treeselection):
         model, aiter = treeselection.get_selected()
@@ -588,8 +597,11 @@ class DVBDaemonPlugin(totem.Plugin):
             name = _("Recording %d") % rid
         else:
             name = escape(name)
-        self.channels.append(self.rec_iter, [self.REC_GROUP_ID, name, rid, None])
-                
+        aiter = self.channels.append(self.rec_iter)
+        self.channels[aiter][ChannelsTreeStore.COL_GROUP_ID] = self.REC_GROUP_ID
+        self.channels[aiter][ChannelsTreeStore.COL_NAME] = name
+        self.channels[aiter][ChannelsTreeStore.COL_SID] = rid
+
     def _on_recstore_changed(self, recstore, rec_id, change_type):
         if change_type == 0:
             # Added
@@ -605,7 +617,7 @@ class DVBDaemonPlugin(totem.Plugin):
                 child_iter = self.channels.iter_next(child_iter)
                 
     def _on_channels_row_inserted_deleted(self, treestore, path, aiter=None):
-        if len(path) == 1:
+        if path.get_depth() == 1:
             # One entry is for recordings
             val = len(treestore) == 2
             self._enable_single_group_mode(val)
@@ -615,11 +627,11 @@ class DVBDaemonPlugin(totem.Plugin):
         if self._loaded_groups == self._size:
             self._configure_mode()
                         
-    def _delete_callback(self, success):
+    def _delete_callback(self, proxy, success, user_data):
         if not success:
             global_error_handler("Could not delete recording")
             
-    def _on_order_by_changed(self, action, current):
+    def _on_order_by_changed(self, action, current, user_date=None):
         val = current.get_current_value()
         sort_order = self.channels.get_sort_column_id()[1]
         if val == self.ORDER_BY_NAME_ID:
@@ -627,28 +639,23 @@ class DVBDaemonPlugin(totem.Plugin):
         elif val == self.ORDER_BY_GROUP_ID:
             self.channels = ChannelsTreeStore(True)
         self.channels.set_sort_order(sort_order)
+        self._get_and_add_recordings()
         self.channels_view.set_model(self.channels)
         
-    def _on_order_reverse_toggled(self, action):
+    def _on_order_reverse_toggled(self, action, user_date=None):
         if action.get_active():
-            self.channels.set_sort_order(gtk.SORT_DESCENDING)
+            self.channels.set_sort_order(Gtk.SortType.DESCENDING)
         else:
-            self.channels.set_sort_order(gtk.SORT_ASCENDING)
+            self.channels.set_sort_order(Gtk.SortType.ASCENDING)
 
-    def _on_play_dvb_activated(self, action):
+    def _on_play_dvb_activated(self, action, user_date=None):
         main_window = self.totem_object.get_main_window()
         # Only run setup if no devices are configured, yet
         if self._size == 0:
             status = self.setup.run (main_window, self._on_setup_dvb_finished)
             if status == DvbSetup.MISSING:
-                dialog = gtk.MessageDialog(main_window,
-                    gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-                    gtk.MESSAGE_ERROR,
-                    gtk.BUTTONS_CLOSE,
+                self.totem_object.action_error(_("Setup Failed"),
                     _("GNOME DVB Daemon is not installed"))
-                dialog.set_resizable(False)
-                dialog.run()
-                dialog.destroy()
 
             print "DVB SETUP STARTED", status
 
